/**
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof assert>} Assert
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof location>} AssertLocation
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof inclusion>} AssertInclusion
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof partition>} AssertPartition
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof relation>} AssertRelation
 * @typedef {import('@ucanto/server').InferInvokedCapability<typeof equals>} AssertEquals
 */
export const assert: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/*", import("@ucanto/interface").URI<"did:">, {}>>;
/**
 * Claim that a CID is available at a URL.
 */
export const location: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/location", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    location: Schema.ArraySchema<import("@ucanto/interface").URI<`${string}:`>, unknown>;
    range: Schema.Schema<Schema.InferStruct<{
        offset: Schema.NumberSchema<number & import("@ucanto/server").Phantom<{
            typeof: "integer";
        }>, unknown>;
        length: Schema.Schema<(number & import("@ucanto/server").Phantom<{
            typeof: "integer";
        }>) | undefined, unknown>;
    }> | undefined, unknown>;
}>>>;
/**
 * Claims that a CID includes the contents claimed in another CID.
 */
export const inclusion: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/inclusion", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    includes: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
    proof: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1> | undefined, any>;
}>>>;
/**
 * Claims that a CID's graph can be read from the blocks found in parts.
 */
export const partition: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/partition", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    blocks: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1> | undefined, any>;
    parts: Schema.ArraySchema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
}>>>;
/**
 * Claims that a CID links to other CIDs.
 */
export const relation: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/relation", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    children: Schema.ArraySchema<import("@ucanto/server").IPLDLink<unknown, number, number, 0 | 1>, unknown>;
    parts: Schema.ArraySchema<Schema.InferStruct<{
        content: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
        includes: Schema.Schema<Schema.InferStruct<{
            content: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>, any>;
            parts: Schema.Schema<import("@ucanto/server").IPLDLink<unknown, number, number, 1>[] | undefined, any>;
        }> | undefined, unknown>;
    }>, any>;
}>>>;
/**
 * Claim data is referred to by another CID and/or multihash. e.g CAR CID & CommP CID
 */
export const equals: import("@ucanto/server").TheCapabilityParser<import("@ucanto/server").CapabilityMatch<"assert/equals", import("@ucanto/interface").URI<"did:">, Schema.InferStruct<{
    content: typeof Link;
    equals: typeof Link;
}>>>;
export type Assert = import('@ucanto/server').InferInvokedCapability<typeof assert>;
export type AssertLocation = import('@ucanto/server').InferInvokedCapability<typeof location>;
export type AssertInclusion = import('@ucanto/server').InferInvokedCapability<typeof inclusion>;
export type AssertPartition = import('@ucanto/server').InferInvokedCapability<typeof partition>;
export type AssertRelation = import('@ucanto/server').InferInvokedCapability<typeof relation>;
export type AssertEquals = import('@ucanto/server').InferInvokedCapability<typeof equals>;
import { Link } from '@ucanto/server';
import { Schema } from '@ucanto/server';
//# sourceMappingURL=assert.d.ts.map